
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.29.4',
    'branch_nick': 'release-1.29-LTS',
    'revision_id': '1e1e610a86d4089ac1f017df41da6465274429fd',
    'revno': 12018
}
